@@ -234,11 +234,11 @@ class UsersideAPI:
         self._url = url
         self._key = key
         self._session = None
-        self._register_category('device', Device)
-        self._register_category('commutation', Commutation)
-        self._register_category('customer', Customer)
-        self._register_category('node', Node)
-        self._register_category('task', Task)
+        self.device = Device(self)
+        self.commutation = Commutation(self)
+        self.customer= Customer(self)
+        self.node = Node(self)
+        self.task = Task(self)
 
     def __getattr__(self, item):
         return GenericUsersideCategory(item, self)
@@ -266,9 +266,6 @@ class UsersideAPI:
             return json.loads(content)
         raise ValueError(error_message)
 
-    def _register_category(self, category_name: str, category_class):
-        setattr(self, category_name, category_class(self))
-
     async def __aenter__(self):
         self._session = aiohttp.ClientSession()
         return self
