@@ -145,10 +145,10 @@ class UsersideAPI:
         self._url = url
         self._key = key
         self._session = None
-        self._register_category('device', Device)
-        self._register_category('commutation', Commutation)
-        self._register_category('customer', Customer)
-        self._register_category('node', Node)
+        self.device = Device(self)
+        self.commutation = Commutation(self)
+        self.customer = Customer(self)
+        self.node = Node(self)
 
     def __getattr__(self, item):
         return GenericUsersideCategory(item, self)
@@ -179,9 +179,6 @@ class UsersideAPI:
             raise requests.HTTPError(error_message)
         return answer
 
-    def _register_category(self, category_name: str, category_class):
-        setattr(self, category_name, category_class(self))
-
     def __enter__(self):
         self._session = requests.Session()
         return self
